package com.bonus.canteen.core.cook.mapper;

import java.util.List;
import com.bonus.canteen.core.cook.domain.CookRecipeBindDevice;

/**
 * 设备绑定多档口子Mapper接口
 * 
 * @author xsheng
 * @date 2025-05-25
 */
public interface CookRecipeBindDeviceMapper {
    /**
     * 查询设备绑定多档口子
     * 
     * @param id 设备绑定多档口子主键
     * @return 设备绑定多档口子
     */
    public CookRecipeBindDevice selectCookRecipeBindDeviceById(Long id);

    /**
     * 查询设备绑定多档口子列表
     * 
     * @param cookRecipeBindDevice 设备绑定多档口子
     * @return 设备绑定多档口子集合
     */
    public List<CookRecipeBindDevice> selectCookRecipeBindDeviceList(CookRecipeBindDevice cookRecipeBindDevice);

    /**
     * 新增设备绑定多档口子
     * 
     * @param cookRecipeBindDevice 设备绑定多档口子
     * @return 结果
     */
    public int insertCookRecipeBindDevice(CookRecipeBindDevice cookRecipeBindDevice);

    /**
     * 修改设备绑定多档口子
     * 
     * @param cookRecipeBindDevice 设备绑定多档口子
     * @return 结果
     */
    public int updateCookRecipeBindDevice(CookRecipeBindDevice cookRecipeBindDevice);

    /**
     * 删除设备绑定多档口子
     * 
     * @param id 设备绑定多档口子主键
     * @return 结果
     */
    public int deleteCookRecipeBindDeviceById(Long id);

    /**
     * 批量删除设备绑定多档口子
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCookRecipeBindDeviceByIds(Long[] ids);
}
