package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.cook.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.cook.domain.CookRecipeBindDevice;
import com.bonus.canteen.core.cook.service.ICookRecipeBindDeviceService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 设备绑定多档口子Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "设备绑定多档口子接口")
@RestController
@RequestMapping("/cook_recipe_bind_device")
public class CookRecipeBindDeviceController extends BaseController {
    @Autowired
    private ICookRecipeBindDeviceService cookRecipeBindDeviceService;

    /**
     * 查询设备绑定多档口子列表
     */
    @ApiOperation(value = "查询设备绑定多档口子列表")
    //@RequiresPermissions("cook:device:list")
    @GetMapping("/list")
    public TableDataInfo list(CookRecipeBindDevice cookRecipeBindDevice) {
        startPage();
        List<CookRecipeBindDevice> list = cookRecipeBindDeviceService.selectCookRecipeBindDeviceList(cookRecipeBindDevice);
        return getDataTable(list);
    }

    /**
     * 导出设备绑定多档口子列表
     */
    @ApiOperation(value = "导出设备绑定多档口子列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:device:export")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出设备绑定多档口子")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookRecipeBindDevice cookRecipeBindDevice) {
        List<CookRecipeBindDevice> list = cookRecipeBindDeviceService.selectCookRecipeBindDeviceList(cookRecipeBindDevice);
        ExcelUtil<CookRecipeBindDevice> util = new ExcelUtil<CookRecipeBindDevice>(CookRecipeBindDevice.class);
        util.exportExcel(response, list, "设备绑定多档口子数据");
    }

    /**
     * 获取设备绑定多档口子详细信息
     */
    @ApiOperation(value = "获取设备绑定多档口子详细信息")
    //@RequiresPermissions("cook:device:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(cookRecipeBindDeviceService.selectCookRecipeBindDeviceById(id));
    }

    /**
     * 新增设备绑定多档口子
     */
    @ApiOperation(value = "新增设备绑定多档口子")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:device:add")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增设备绑定多档口子")
    @PostMapping
    public AjaxResult add(@RequestBody CookRecipeBindDevice cookRecipeBindDevice) {
        try {
            return toAjax(cookRecipeBindDeviceService.insertCookRecipeBindDevice(cookRecipeBindDevice));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改设备绑定多档口子
     */
    @ApiOperation(value = "修改设备绑定多档口子")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:device:edit")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改设备绑定多档口子")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookRecipeBindDevice cookRecipeBindDevice) {
        try {
            return toAjax(cookRecipeBindDeviceService.updateCookRecipeBindDevice(cookRecipeBindDevice));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除设备绑定多档口子
     */
    @ApiOperation(value = "删除设备绑定多档口子")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:device:remove")
    @SysLog(title = "设备绑定多档口子", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除设备绑定多档口子")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(cookRecipeBindDeviceService.deleteCookRecipeBindDeviceByIds(ids));
    }
}
